Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Command ¶
type Command func()
Command is the basic interface for all actions executable by a hotkey
type Commander ¶
type Commander struct {
// contains filtered or unexported fields
}
Commander creates bindings for hotkeys to functions
func (*Commander) Apply ¶
func (commander *Commander) Apply(config *Config, activeConfig actions.ActiveConfig)
Apply will apply the current configuration and its hotkey bindings deleting the previous ones
func (*Commander) Bind ¶
func (commander *Commander) Bind(vkey int32, alt bool, ctrl bool, shift bool, win bool, command Command) bool
Bind will attach a command to a hotkey
func (*Commander) HandleHotkey ¶
HandleHotkey must be called during handling of the WM_HOTKEY event
func (*Commander) NewCommander ¶
func (commander *Commander) NewCommander()
NewCommander creates a new initialized element
Click to show internal directories.
Click to hide internal directories.